@@ -106,11 +106,14 @@ def is_ip_address(string_to_check):
     return False
 
 
-def resolve_dns(domain, dns_server=None, first_result_only=True):
-    """Resolves the domain to an IP address. If a DNS server is provided, it will use that server.
+def resolve_dns(domain, timeout=5, lifetime=15, dns_server=None, first_result_only=True):
+    """Resolves the domain to an IP address. If no DNS server is provided, it will use the system's default DNS server.
+    Timeout and lifetime are set to 5 and 15 seconds respectively by default.
 
     Args:
         domain (str): The domain to resolve.
+        timeout (int, optional): The timeout for the DNS resolver. Defaults to 5.
+        lifetime (int, optional): The lifetime for the DNS resolver. Defaults to 10.
         dns_server (str, optional): The DNS server to use. Defaults to None.
         first_result_only (bool, optional): Whether to return only the first result. Defaults to True.
 
@@ -125,9 +128,10 @@ def resolve_dns(domain, dns_server=None, first_result_only=True):
 
     # Initialize the resolver
     resolver = dns.resolver.Resolver()
+    resolver.timeout = timeout
+    resolver.lifetime = lifetime
     logging.debug("Initialized DNS resolver.")
 
-    # Set the DNS server if provided
     # Set the DNS server if provided
     if dns_server:
         resolver.nameservers = [dns_server]
